Changelog
==========

0.5.5
------

Support for arbitrary data attribute.

0.5.1
-----

Fix package descriptions and doc links.

0.5
-----

First version based on `django-activity-stream <https://github.com/justquick/django-activity-stream>`_ v0.4.3

